pkgsrc-WIP-changes archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

rust184: re-do patch to fix use of external LLVM.



Module Name:	pkgsrc-wip
Committed By:	Havard Eidnes <he%NetBSD.org@localhost>
Pushed By:	he
Date:		Mon Feb 3 19:20:26 2025 +0000
Changeset:	5598b84ca0a7a9ede69252af98ae98738702f905

Modified Files:
	rust184/distinfo
	rust184/patches/patch-src_bootstrap_src_core_builder_cargo.rs

Log Message:
rust184: re-do patch to fix use of external LLVM.

Luckily, we already had a "pick up external libunwind on Linux"
patch, which is now "pick up libs in @PREFIX@/lib on pkgsrc", i.e.
irrespective of OS.

To see a diff of this commit:
https://wip.pkgsrc.org/cgi-bin/gitweb.cgi?p=pkgsrc-wip.git;a=commitdiff;h=5598b84ca0a7a9ede69252af98ae98738702f905

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

diffstat:
 rust184/distinfo                                              |  2 +-
 rust184/patches/patch-src_bootstrap_src_core_builder_cargo.rs | 10 ++++------
 2 files changed, 5 insertions(+), 7 deletions(-)

diffs:
diff --git a/rust184/distinfo b/rust184/distinfo
index b50b645020..14339e8210 100644
--- a/rust184/distinfo
+++ b/rust184/distinfo
@@ -121,7 +121,7 @@ SHA1 (patch-library_stdarch_crates_std__detect_tests_cpu-detection.rs) = 97c3ad8
 SHA1 (patch-src_bootstrap_bootstrap.py) = 150a5a7e057de9edbf96f3c387207fda8ba750f9
 SHA1 (patch-src_bootstrap_src_core_build__steps_compile.rs) = e928203ed4734c93cc33c5a3f7879cf18dcecc83
 SHA1 (patch-src_bootstrap_src_core_build__steps_install.rs) = cc6558df42c9c9ac28fdb2ff180bdaa7f22ce816
-SHA1 (patch-src_bootstrap_src_core_builder_cargo.rs) = 26aa32be90d0448cf22d07764d6136b063bfa00d
+SHA1 (patch-src_bootstrap_src_core_builder_cargo.rs) = 8aa36577fffd8d02cdd72151f42f5b1c971f2be5
 SHA1 (patch-src_bootstrap_src_lib.rs) = d29bc3c0b335d5e788eecbb02fc08966beef0fb1
 SHA1 (patch-src_llvm-project_llvm_CMakeLists.txt) = 7abfabb6ec70df229a69355f8c76825610165c37
 SHA1 (patch-src_llvm-project_llvm_cmake_modules_AddLLVM.cmake) = e1b2eb2f0b3cf1cf87b443656ae306b3242f6b12
diff --git a/rust184/patches/patch-src_bootstrap_src_core_builder_cargo.rs b/rust184/patches/patch-src_bootstrap_src_core_builder_cargo.rs
index 8efc1a0095..e2c2f4f79b 100644
--- a/rust184/patches/patch-src_bootstrap_src_core_builder_cargo.rs
+++ b/rust184/patches/patch-src_bootstrap_src_core_builder_cargo.rs
@@ -1,6 +1,6 @@
 $NetBSD$
 
-Find external libunwind on Linux.
+Find external libunwind and libLLVM in pkgsrc (not just Linux).
 Use @PREFIX@ in rpath.
 
 Adapt fix to
@@ -21,14 +21,12 @@ https://github.com/rust-lang/rust/issues/133629
                          .arg("--target")
                          .arg(target.rustc_target_arg())
                          .arg("--print=file-names")
-@@ -1198,6 +1201,11 @@ impl Builder<'_> {
+@@ -1198,6 +1201,9 @@ impl Builder<'_> {
              rustflags.arg("-Zinline-mir-preserve-debug");
          }
  
-+        // added for pkgsrc libunwind
-+        if target.contains("linux") {
-+                rustflags.arg("-Clink-args=-Wl,-rpath,@PREFIX@/lib,-L@PREFIX@/lib");
-+        }
++        // added for pkgsrc libunwind or external LLVM
++        rustflags.arg("-Clink-args=-Wl,-rpath,@PREFIX@/lib,-L@PREFIX/lib");
 +
          Cargo {
              command: cargo,


Home | Main Index | Thread Index | Old Index